@@ -1,6 +1,7 @@
 <?
 /*
- Copyright (C) 2004 Christian Mauduit <ufoot@ufoot.org>
+ UWiKiCMS is a lightweight web content management system.
+ Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -14,8 +15,8 @@
 
  You should have received a copy of the GNU General Public
  License along with this program; if not, write to the Free
- Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- MA 02111-1307 USA
+ Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+ MA  02110-1301  USA
 */
 
 $this->messages=array
@@ -60,7 +61,7 @@ $this->messages=array
    "status_1"=>"Prot&eacute;g&eacute; par un mot de passe",
    "status_2"=>"Priv&eacute;",
    "status_3"=>"Confidentiel",
-   "rights_0"=>"Copyleft &copy; %s %s (<a href=\"http://www.gnu.org/copyleft/fdl.html\">GNU FDL</a>).",
+   "rights_0"=>"Copyright &copy; %s %s. Document plac&eacute; sous licence <a href=\"http://www.gnu.org/copyleft/fdl.html\">GNU FDL</a>.",
    "rights_1"=>"L'acc&egrave;s &agrave; cette page est prot&eacute;g&eacute; par un mot de passe.",
    "rights_2"=>"Document priv&eacute;.",
    "rights_3"=>"Document confidentiel.",
