@@ -1,4 +1,25 @@
 <?
+/*
+ UWiKiCMS is a lightweight web content management system.
+ Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
+
+ This program is free software; you can redistribute it and/or
+ modify it under the terms of the GNU General Public License as
+ published by the Free Software Foundation; either version 2 of
+ the License, or (at your option) any later version.
+
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
+
+ You should have received a copy of the GNU General Public
+ License along with this program; if not, write to the Free
+ Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+ MA  02110-1301  USA
+*/
+?>
+<?
 echo "<?xml version=\"1.0\" encoding=\"ISO-8859-1\" ?>\n";
 echo "<?xml-stylesheet href=\"chrome://global/skin/\" type=\"text/css\"?>\n";
 ?>
